EzGP PackageCalculates the log-likelihood function value and the analytical gradients as described in reference 1.
LLF_gradients(X, Y, p, q, m, parv, tau = 0, models = 0)A list of the following items:
objective The log-likelihood function value.
gradient The analytical gradients.
Matrix or data frame containing the inputs of training data. Each row represents the input setting of a data point and the columns are values of quantitative variables and qualitative variables.
Vector containing the outputs of training data points.
Number of quantitative factors in the given dataset X.
Number of qualitative factors in the given dataset X.
A vector containing numbers of levels in qualitative factors.
Parameters in the EzGP/EEzGP model.
Nugget if needed. The default nugget is 0, otherwise it has to be a non-negative real value.
Model indicator that indicates which model the likelihoods and analytical gradients are applied to. 0 for EzGP model, 1 for EEzGP model.
"EzGP: Easy-to-Interpret Gaussian Process Models for Computer Experiments with Both Quantitative and Qualitative Factors", Qian Xiao, Abhyuday Mandal, C. Devon Lin, and Xinwei Deng (tools:::Rd_expr_doi("10.1137/19M1288462"))
EzGP_fit to see how an EzGP model can be fitted to a training dataset.
EzGP_predict to use the fitted EzGP model for prediction.
EEzGP_fit to see how an EEzGP model can be fitted to a training dataset.
EEzGP_predict to use the fitted EEzGP model for prediction.
LEzGP_fit to see how a LEzGP model can be fitted to a training dataset.
# see the examples in the documentation of the function EzGP_fit.
Run the code above in your browser using DataLab