EzGP PackageBuilds the covariance matrix for the given dataset according to different models.
cov_m(X, p, q, m, n, parv, tau = 0, models = 0)The covariance matrix for the given dataset.
Matrix or data frame containing the inputs of training data. Each row represents the input setting of a data point and the columns are values of quantitative variables and qualitative variables.
Number of quantitative factors in the given dataset X.
Number of qualitative factors in the given dataset X.
A vector containing numbers of levels in qualitative factors.
Number of training data points
Parameters in the EzGP/EEzGP model
Nugget if needed. The default nugget is 0, otherwise it has to be a non-negative real value.
Model indicator that indicates which model the covariance matrix is built for. 0 for EzGP model, 1 for EEzGP model. The default setting is 0.
EzGP_fit, EzGP_predict, EEzGP_fit, EEzGP_predict, LEzGP_fit, and LLF_gradients will call this function.
"EzGP: Easy-to-Interpret Gaussian Process Models for Computer Experiments with Both Quantitative and Qualitative Factors", Qian Xiao, Abhyuday Mandal, C. Devon Lin, and Xinwei Deng (tools:::Rd_expr_doi("10.1137/19M1288462"))
EzGP_fit to see how an EzGP model can be fitted to a training dataset.
EzGP_predict to use the fitted EzGP model for prediction.
EEzGP_fit to see how an EEzGP model can be fitted to a training dataset.
EEzGP_predict to use the fitted EEzGP model for prediction.
LEzGP_fit to see how a LEzGP model can be fitted to a training dataset.
# see the examples in the documentation of the function EzGP_fit.
Run the code above in your browser using DataLab